import argparse
from typing import cast

from delta.tables import DeltaTable
from pyspark.sql import SparkSession

from trend_etl.functions.delta import (
    full_table_name,
    ao_merge_using_ingestion_key,
)
from trend_etl.transform.subreddits import from_bronze_get_subreddits_df_ao
import trend_etl.schema.args as arguments

program = "load_subreddits_ao"


def main() -> None:
    print("test code artifact")

    parser = argparse.ArgumentParser(description=f"Arguments for Trend ETL/{program}.")

    parser.add_argument(
        "--bronze-catalog",
        dest="bronze_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unit catalog to use",
    )

    parser.add_argument(
        "--target-catalog",
        dest="target_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unit catalog to use",
    )

    parser.add_argument(
        "--checkpoints-path-prefix",
        dest="checkpoints_path_prefix",
        required=True,
        help="The path to the folder (in S3) to store the checkpoints for this table",
    )

    args = parser.parse_args()

    spark = cast(SparkSession, SparkSession.builder.appName(program).getOrCreate())

    kafka_subreddits_table = full_table_name(
        args.bronze_catalog,
        arguments.schemas[arguments.schemas_bronze],
        arguments.tables[arguments.tables_subreddits_daily],
    )
    streaming_kafka_subreddits = spark.readStream.format("delta").table(
        kafka_subreddits_table
    )

    subreddit_idents_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_subreddit_idents],
    )
    subreddit_idents = spark.read.format("delta").table(subreddit_idents_table)

    subreddits_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_subreddits_ao],
    )

    prepared = from_bronze_get_subreddits_df_ao(
        streaming_kafka_subreddits, subreddit_idents
    )

    checkpoint_loc = f"{args.checkpoints_path_prefix}/subreddits_ao"
    delta_table = DeltaTable.forName(spark, subreddits_table)

    (
        prepared.writeStream.format("delta")
        .foreachBatch(
            lambda batch_df, batch_id: ao_merge_using_ingestion_key(
                delta_table, batch_df
            )
        )
        .option("checkpointLocation", checkpoint_loc)
        .outputMode("append")
        .trigger(availableNow=True)
        .start()
    )


if __name__ == "__main__":
    main()
