import argparse
from typing import cast

from pyspark.sql import SparkSession

from trend_etl.functions.delta import full_table_name
import trend_etl.schema.args as arguments
import trend_etl.transform.gold as gold

program = "materialize_nlp_results"


def main() -> None:
    parser = argparse.ArgumentParser(description=f"Arguments for Trend ETL/{program}.")

    parser.add_argument(
        "--silver-catalog",
        dest="silver_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The catalog to use",
    )

    parser.add_argument(
        "--gold-catalog",
        dest="gold_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The catalog to use",
    )

    args = parser.parse_args()

    spark = cast(SparkSession, SparkSession.builder.appName(program).getOrCreate())

    silver_table = spark.read.format("delta").table(
        full_table_name(
            args.silver_catalog,
            arguments.schemas[arguments.schemas_silver],
            arguments.tables[arguments.tables_historical_prod_nlp_results_new_version],
        )
    )

    gold_tablename = full_table_name(
        args.gold_catalog,
        arguments.schemas[arguments.schemas_gold],
        "nlp_results",
    )

    (
        gold.facebook_subset(spark, args.silver_catalog)
        .unionAll(gold.reddit_subset(spark, args.silver_catalog))
        .unionAll(gold.discord_subset(spark, args.silver_catalog))
        .join(silver_table, "text_version")
        .write.format("delta")
        .mode("overwrite")
        .saveAsTable(gold_tablename)
    )


if __name__ == "__main__":
    main()
