from pyspark.sql import SparkSession, DataFrame
import pyspark.sql.functions as fn

from trend_etl.functions.delta import full_table_name
import trend_etl.schema.args as arguments


def reddit_subset(
    spark: SparkSession,
    silver_catalog: str,
) -> DataFrame:
    subreddits = spark.read.format("delta").table(
        full_table_name(
            silver_catalog,
            arguments.schemas[arguments.schemas_gold],
            "subreddits",
        )
    )
    reddit_submissions = spark.read.format("delta").table(
        full_table_name(
            silver_catalog,
            arguments.schemas[arguments.schemas_gold],
            "reddit_submissions",
        )
    )
    reddit_replies = spark.read.format("delta").table(
        full_table_name(
            silver_catalog,
            arguments.schemas[arguments.schemas_gold],
            "reddit_replies",
        )
    )

    return (
        reddit_submissions.alias("rs")
        .join(
            subreddits.alias("s"),
            fn.col("s.source_keys.name") == fn.col("rs.source_keys.subreddit_id"),
            "left_outer",
        )
        .select(
            fn.col("s.group_id").alias("group_id"),
            fn.col("rs.doc_uuid").alias("doc_uuid"),
            fn.col("rs.text_version").alias("text_version"),
        )
        .unionAll(
            reddit_replies.alias("rr")
            .join(
                subreddits.alias("s"),
                fn.col("s.source_keys.name") == fn.col("rr.source_keys.subreddit_id"),
                "left_outer",
            )
            .select(
                fn.col("s.group_id").alias("group_id"),
                fn.col("rr.doc_uuid").alias("doc_uuid"),
                fn.col("rr.text_version").alias("text_version"),
            )
        )
    )


def facebook_subset(
    spark: SparkSession,
    silver_catalog: str,
) -> DataFrame:
    facebook_groups = spark.read.format("delta").table(
        full_table_name(
            silver_catalog,
            arguments.schemas[arguments.schemas_gold],
            "facebook_groups",
        )
    )
    facebook_posts = spark.read.format("delta").table(
        full_table_name(
            silver_catalog,
            arguments.schemas[arguments.schemas_gold],
            "facebook_posts",
        )
    )
    facebook_comments = spark.read.format("delta").table(
        full_table_name(
            silver_catalog,
            arguments.schemas[arguments.schemas_gold],
            "facebook_comments",
        )
    )

    return (
        facebook_posts.alias("p")
        .join(
            facebook_groups.alias("g"),
            fn.col("g.source_keys.id") == fn.col("p.source_keys.group_id"),
            "left_outer",
        )
        .select(
            fn.col("g.group_id").alias("group_id"),
            fn.col("p.doc_uuid").alias("doc_uuid"),
            fn.col("p.text_version").alias("text_version"),
        )
        .unionAll(
            facebook_comments.alias("c")
            .join(
                facebook_groups.alias("g"),
                fn.col("g.source_keys.id") == fn.col("c.source_keys.group_id"),
                "left_outer",
            )
            .select(
                fn.col("g.group_id").alias("group_id"),
                fn.col("c.doc_uuid").alias("doc_uuid"),
                fn.col("c.text_version").alias("text_version"),
            )
        )
    )


def discord_subset(
    spark: SparkSession,
    silver_catalog: str,
) -> DataFrame:
    discord_guilds = spark.read.format("delta").table(
        full_table_name(
            silver_catalog,
            arguments.schemas[arguments.schemas_gold],
            "discord_guilds",
        )
    )
    discord_channels = spark.read.format("delta").table(
        full_table_name(
            silver_catalog,
            arguments.schemas[arguments.schemas_gold],
            "discord_channels",
        )
    )
    discord_messages = spark.read.format("delta").table(
        full_table_name(
            silver_catalog,
            arguments.schemas[arguments.schemas_gold],
            "discord_messages",
        )
    )

    return (
        discord_messages.alias("m")
        .join(
            discord_channels.alias("c"),
            fn.col("c.source_keys.id") == fn.col("m.source_keys.channel_id"),
            "left_outer",
        )
        .join(
            discord_guilds.alias("g"),
            fn.col("g.source_keys.id") == fn.col("c.source_keys.guild_id"),
            "left_outer",
        )
        .select(
            fn.col("g.group_id").alias("group_id"),
            fn.col("m.doc_uuid").alias("doc_uuid"),
            fn.col("m.text_version").alias("text_version"),
        )
    )
